@@ -12,7 +12,8 @@ import sys
 import cmd
 import time
 import logging
-from client import API
+
+from .client import Client
 
 logging.basicConfig(level=logging.INFO, format='[%(asctime)s] %(message)s')
 logger = logging.getLogger('sshpool.ctl')
@@ -27,16 +28,16 @@ class Ctl(cmd.Cmd):
         cmd.Cmd.__init__(self)
         self.host = host
         self.port = port
-        self.api = API(self.host, self.port)
+        self.client = Client(self.host, self.port)
     
     def out(self, line):
         if line is not None:
             if isinstance(line, unicode):
                 line = line.encode('utf-8')
-            self.stdout.write(line + '\n')
+            self.stdout.write('%s\n' % line)
     
     def do_status(self, alias):
-        r = self.api.status(alias)
+        r = self.client.status(alias)
         
         if r is None: 
             return
@@ -45,7 +46,7 @@ class Ctl(cmd.Cmd):
             resp = r.json()
             for alias in resp:
                 info = resp[alias]
-                dsn = '%s:%s@%s:%s' % (info['username'], info['password'], info['hostname'], info['port'])
+                dsn = '%s:%s@%s:%s' % (info['user'], info['pass'], info['host'], info['port'])
                 status = "running" if info['is_alive'] else "dead"
                 uptime = int(time.time() - info['start_time'])
                 self.out('%s\t\t%s\t%s\t%s' % (alias, dsn, status, uptime))
@@ -56,7 +57,7 @@ class Ctl(cmd.Cmd):
         self.out('status\t\tView status of started channels')
     
     def do_start(self, dsn):
-        r = self.api.start(dsn)
+        r = self.client.start(dsn)
         if r is None: 
             return
         
@@ -72,13 +73,17 @@ class Ctl(cmd.Cmd):
         args = arg.split()
         alias = args[0]
         cmd = ' '.join(args[1:])
-        r = self.api.run(alias, cmd)
         
+        r = self.client.run(alias, cmd)
         if r is None: 
             return
         
         if r.status_code == 200:
-            self.out(r.text)
+            resp = r.json()
+            if resp['exit_code'] == 0:
+                self.out(resp['stdout'])
+            else:
+                self.out(resp['stderr'])
         else:
             self.out(r.status_code)
     
@@ -86,7 +91,7 @@ class Ctl(cmd.Cmd):
         self.out('run <alias> <cmd>\tRun arbitrary commands over a channel')
     
     def do_stop(self, alias):
-        r = self.api.stop(alias)
+        r = self.client.stop(alias)
         
         if r is None: 
             return
